Package: fRegression
Title: Rmetrics - Regression Based Decision and Prediction
Date: 2022-08-11
Version: 4021.83
Authors@R: c(person("Diethelm", "Wuertz", role = "aut")
	   , person("Tobias", "Setz", role = "aut")
	   , person("Yohan", "Chalabi", role = "aut")
	   , person(given = c("Paul", "J."), family = "Northrop", 
                    role = c("cre", "ctb"), email = "p.northrop@ucl.ac.uk") )
Description: A collection of functions for linear and non-linear regression 
  modelling. It implements a wrapper for several regression models available 
  in the base and contributed packages of R. 
Depends: R (>= 2.15.1)
Imports: fBasics, lmtest, MASS, methods, mgcv, nnet, polspline, stats,
        timeDate, timeSeries, utils
Suggests: RUnit
License: GPL (>= 2)
URL: https://www.rmetrics.org
BugReports: https://r-forge.r-project.org/projects/rmetrics
NeedsCompilation: no
Packaged: 2022-08-11 09:25:20 UTC; paul
Author: Diethelm Wuertz [aut],
  Tobias Setz [aut],
  Yohan Chalabi [aut],
  Paul J. Northrop [cre, ctb]
Maintainer: Paul J. Northrop <p.northrop@ucl.ac.uk>
Repository: CRAN
Date/Publication: 2022-08-11 09:40:19 UTC
Built: R 4.6.0; ; 2026-04-27 16:58:02 UTC; unix
